@@ -30,15 +30,25 @@ Pique et pique et colgram
 Bourre, bourre et ratatam
 Am, stram, gram.
 
-=head1 CONTRIBUTOR
+=head2 DUTCH
+
+Iene, miene, mutte,
+tien pond grutten,
+tien pond kaas,
+Iene, miene, mutte,
+is de baas.
+
+=head1 CONTRIBUTORS
 
 Xavier Caron proposed the idea in French, and Paul-Christophe Varoutas
-provided the English version.
+provided the English version. Abigail provided the Dutch version.
 
 Introduced in version 0.30, published on July 11, 2005.
 
 Patched a typo in version 0.39, published on September 12, 2005.
 
+Updated with the Dutch theme in version 0.47, published on November 7, 2005.
+
 =head1 SEE ALSO
 
 L<Acme::MetaSyntactic>, L<Acme::MetaSyntactic::List>.
@@ -56,4 +66,8 @@ if he hollers let him go
 am stram gram
 pique et colegram
 bourre ratatam
- 
+# names nl 
+iene miene mutte
+tien pond grutten
+kaas is de baas
+
